==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Rulers and Scrollbars</source>
        <translation>Righelli e barre di scorrimento</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Mostra righelli</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Mostra barre di scorrimento</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Cursore</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Mostra reticolo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Mostra reticolo grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Griglia</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Scala automaticamente la griglia</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Linne griglia spesse</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Spaziatura griglia minima (px):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Scala automaticamente la griglia meta</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Zoom automatico</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Margin (px):</source>
        <translation>Margine (px):</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Color Adjustment</source>
        <translation>Regolazione colore</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Auto corretti colori bianco e nero</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Soglia per la leggerezza del colore:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Tipi di linea</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Scala del modello per lo spessore di linea 0,00mm:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Utilizzare automaticamente i tipi di linea a base di schermo in vista del modello</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Auto switch linetypes</source>
        <translation>Regolare automaticamente i tipi di linea</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Performance</source>
        <translation>Performance</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Number of preview entities:</source>
        <translation>Numero di entità in anteprima:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Visualizzare limite per il testo (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Mostra archi come linee di sotto di questo angolo (gradi):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Visualizzare limite per il testo:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Selection</source>
        <translation>Selezione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Selezione permanente</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Mostra righelli</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Mostra barre di scorrimento</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostra reticolo</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Mostra reticolo grande</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Righelli e barre di scorrimento</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostra barre di scorrimento</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
&amp;Evidenzia gli oggetti al passaggio del mouse
Evidenzia gli oggetti al passaggio del mouse
Il file immagine del cursore della skin &apos;%1&apos; non esiste.</translatorcomment>
        <translation type="obsolete">Cursore</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Griglia</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Scala automaticamente la griglia</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Linne griglia spesse</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Spaziatura griglia minima (px):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Zoom automatico</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Regolazione colore</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Auto corretti colori bianco e nero</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Soglia per la leggerezza del colore:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Performance</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Visualizzare limite per il testo:</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="obsolete">Zoom</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Margine (px):</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Anteprima</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Numero di entità in anteprima:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un blocco nuovo dalle entità esistenti
Crea un blocco nuovo dalle entità esistenti

Deseleziona Tutti gli Oggetti</translatorcomment>
        <translation type="obsolete">Entità</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Auto corretti colori bianco e nero</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Selezione</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Selezioni &amp;persistenti
Selezioni persistenti</translatorcomment>
        <translation type="obsolete">Selezione permanente</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_it.ts--
Visualizzazione grafica</translatorcomment>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Righelli e barre di scorrimento</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Mostra righelli</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Mostra barre di scorrimento</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Cursore</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Mostra reticolo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Mostra reticolo grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Griglia</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Scala automaticamente la griglia</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Linne griglia spesse</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Spaziatura griglia minima (px):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Scala automaticamente la griglia meta</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Mostra reticolo grande</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Zoom automatico</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Margine (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Zoom automatico dopo il caricamento</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Regolazione colore</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Auto corretti colori bianco e nero</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Soglia per la leggerezza del colore:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Tipi di linea</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Utilizzare automaticamente i tipi di linea a base di schermo in vista del modello</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Scala i modelli di linea a base di spessore di linea</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Scala del modello per lo spessore di linea 0,00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Visualizzazione e prestazioni</translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Visualizza entità con più di N trattini come continuo:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Passo angolo minimo per rendere archi (gradi):</translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation>Utilizzare piena risoluzione per il display Retina</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Antialiasing di default</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Numero massimo di punti di riferimento visualizzati:</translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Timeout per la rappresentazione tratteggio:</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Antialiasing di default</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Utilizzare automaticamente i tipi di linea a base di schermo in vista del modello</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Regolare automaticamente i tipi di linea</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Performance</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Numero di entità in anteprima:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Visualizzare limite per il testo (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Mostra archi come linee di sotto di questo angolo (gradi):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Visualizzare limite per il testo:</translation>
    </message>
    <message>
        <location line="+331"/>
        <source>Selection</source>
        <translation>Selezione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Selezione permanente</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Mostra righelli</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Mostra barre di scorrimento</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostra reticolo</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Mostra reticolo grande</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Righelli e barre di scorrimento</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostra barre di scorrimento</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
&amp;Evidenzia gli oggetti al passaggio del mouse
Evidenzia gli oggetti al passaggio del mouse
Il file immagine del cursore della skin &apos;%1&apos; non esiste.</translatorcomment>
        <translation type="obsolete">Cursore</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Griglia</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Scala automaticamente la griglia</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Linne griglia spesse</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Spaziatura griglia minima (px):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Zoom automatico</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Regolazione colore</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Auto corretti colori bianco e nero</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Soglia per la leggerezza del colore:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Performance</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Visualizzare limite per il testo:</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="obsolete">Zoom</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Margine (px):</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Anteprima</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Numero di entità in anteprima:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un blocco nuovo dalle entità esistenti
Crea un blocco nuovo dalle entità esistenti

Deseleziona Tutti gli Oggetti</translatorcomment>
        <translation type="obsolete">Entità</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Auto corretti colori bianco e nero</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Selezione</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Selezioni &amp;persistenti
Selezioni persistenti</translatorcomment>
        <translation type="obsolete">Selezione permanente</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_it.ts--
Visualizzazione grafica</translatorcomment>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
</context>
</TS>
